@@ -13,22 +13,16 @@ using namespace Eigen;
 // the respective h observations with the smallest absolute residuals
 MatrixXi sparseSubsets(const MatrixXd& x, const VectorXd& y,
   	const double& lambda, const int& h, const MatrixXi& subsets, 
-		const bool& useIntercept, const double& eps, const bool& useGram) {
+    const bool& normalize, const bool& useIntercept, 
+    const double& eps, const bool& useGram) {
 	const int nsamp = subsets.cols();
 	MatrixXi indices(h, nsamp);
 	for(int k = 0; k < nsamp; k++) {
 		// compute lasso fit
-		double intercept;
-		VectorXd coefficients = fastLasso(x, y, lambda, true, subsets.col(k),
-				useIntercept, eps, useGram, intercept);
-		// compute residuals
-		VectorXd residuals;
-		residuals.noalias() = y - x * coefficients;
-		if(useIntercept) {
-			for(int i = 0; i < residuals.size(); i++) {
-				residuals(i) -= intercept;
-			}
-		}
+  	double intercept, crit;
+		VectorXd coefficients, residuals;
+    fastLasso(x, y, lambda, true, subsets.col(k), normalize, useIntercept, 
+        eps, useGram, false, intercept, coefficients, residuals, crit);
 		// find h observations with smallest absolute residuals
 		indices.col(k) = findSmallest(residuals.cwiseAbs(), h);
 	}
@@ -37,7 +31,8 @@ MatrixXi sparseSubsets(const MatrixXd& x, const VectorXd& y,
 
 // R interface to sparseSubsets()
 SEXP R_sparseSubsets(SEXP R_x, SEXP R_y, SEXP R_lambda, SEXP R_h, 
-    SEXP R_subsets, SEXP R_intercept, SEXP R_eps, SEXP R_useGram) {
+    SEXP R_subsets, SEXP R_normalize, SEXP R_intercept, SEXP R_eps, 
+    SEXP R_useGram) {
 	// data initializations
 	NumericMatrix Rcpp_x(R_x);              // predictor matrix
 	const int n = Rcpp_x.nrow(), p = Rcpp_x.ncol();
@@ -54,12 +49,13 @@ SEXP R_sparseSubsets(SEXP R_x, SEXP R_y, SEXP R_lambda, SEXP R_h,
 			subsets(i,j) = Rcpp_subsets(i,j) - 1;
 		}
 	}
+  bool normalize = as<bool>(R_normalize);
 	bool useIntercept = as<bool>(R_intercept);
 	double eps = as<double>(R_eps);
 	bool useGram = as<bool>(R_useGram);
 	// call native C++ function and return results
 	MatrixXi indices = sparseSubsets(x, y, lambda, h, subsets,
-			useIntercept, eps, useGram);
+			normalize, useIntercept, eps, useGram);
 	IntegerVector Rcpp_indices = wrap(indices);
   Rcpp_indices = Rcpp_indices + 1;
   return Rcpp_indices;
